summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/codeeditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/codeeditor.h')
-rw-r--r--umbrello/umbrello/dialogs/codeeditor.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/dialogs/codeeditor.h b/umbrello/umbrello/dialogs/codeeditor.h
index 5f72fc7a..d5c42d1f 100644
--- a/umbrello/umbrello/dialogs/codeeditor.h
+++ b/umbrello/umbrello/dialogs/codeeditor.h
@@ -46,8 +46,8 @@ class CodeEditor : public TQTextEdit
TQ_OBJECT
public:
- explicit CodeEditor ( const TQString & text, const TQString & context = TQString(), CodeViewerDialog * tqparent = 0, const char * name = 0 , CodeDocument * doc = 0);
- explicit CodeEditor ( CodeViewerDialog * tqparent, const char* name = 0, CodeDocument * doc = 0);
+ explicit CodeEditor ( const TQString & text, const TQString & context = TQString(), CodeViewerDialog * parent = 0, const char * name = 0 , CodeDocument * doc = 0);
+ explicit CodeEditor ( CodeViewerDialog * parent, const char* name = 0, CodeDocument * doc = 0);
~CodeEditor ();
// return code viewer state
@@ -63,7 +63,7 @@ protected:
void appendText (CodeClassFieldDeclarationBlock * db );
void appendText (TextBlockList * items);
void appendText (CodeMethodBlock * mb);
- void appendText (CodeComment * comment, TextBlock * tqparent, UMLObject * umlObj = 0, const TQString & compName="");
+ void appendText (CodeComment * comment, TextBlock * parent, UMLObject * umlObj = 0, const TQString & compName="");
void appendText (CodeBlockWithComments * cb );
// Rebuild our view of the document. Happens whenever we change
@@ -83,7 +83,7 @@ protected:
// and 'return' events.
void keyPressEvent ( TQKeyEvent * e );
// (re) load the tqparent code document into the editor
void loadFromDocument();
// specialized popup menu for our tool
@@ -111,7 +111,7 @@ private:
TextBlockList m_textBlockList;
// main insert routine. Will append if startline is not supplied.
- void insert (const TQString & text, TextBlock * tqparent, bool isEditable = false,
+ void insert (const TQString & text, TextBlock * parent, bool isEditable = false,
const TQColor & fgcolor = TQColor("black"), const TQColor & bgcolor = TQColor("white"),
UMLObject * umlobj = 0, const TQString & displayName = "", int startLine = -1);
@@ -83,7 +83,7 @@ protected:
// and 'return' events.
void keyPressEvent ( TQKeyEvent * e );
- // (re) load the tqparent code document into the editor
+ // (re) load the parent code document into the editor
void loadFromDocument();
// specialized popup menu for our tool